time-tracker-app 0.1.2

Tool for clocking in and out as well as adding descriptions
time-tracker-app-0.1.2 is not a library.

time-tracker

CI

Tool for clocking in and out as well as adding descriptions

Create a release with git tag vx.y.z and git push origin tag vx.y.z